/*
 * Copyright 2008 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "condor_common.h"

#include "ScheddPlugin.h"

struct ExampleScheddPlugin : public ScheddPlugin
{
	void
	earlyInitialize()
	{
		printf("EarlyInit\n");
	}

	void
	initialize()
	{
		printf("Init\n");
	}

	void
	shutdown()
	{
		printf("Shutdown\n");
	}

	void update(int cmd, const ClassAd *ad)
	{
		printf("update(%d, %s)\n", cmd, ad ? "Ad" : "(NULL)");
	}

	void archive(const ClassAd *ad)
	{
		printf("archive(%s)\n", ad ? "Ad" : "(NULL)");
	}
};

static ExampleScheddPlugin instance;
